@@ -15,7 +15,7 @@ from .parallel import multi_thread_tasks, multi_process_tasks
 import re
 from tos.utils import SizeAdapter
 import math
-from .utils import write_list_to_txt
+from .io_utils import write_list_to_txt
 
 def _valid_tos_path(path):
     """
